/**
* \file
*
* \brief Empty user application template
*
*/

/**
* \mainpage User Application template doxygen documentation
*
* \par Empty user application template
*
* Bare minimum empty user application template
*
* \par Content
*
* -# Include the ASF header files (through asf.h)
* -# Minimal main function that starts with a call to system_init()
* -# "Insert application code here" comment
*
*/

/*
* Include header files for all drivers that have been imported from
* Atmel Software Framework (ASF).
*/
/*
* Support and FAQ: visit <a href="http://www.atmel.com/design-support/">Atmel Support</a>
*/
#include <asf.h>
extern const unsigned char Microchip_Logo[];
extern const unsigned char WINSTAR_Logo[];

#define LED1	PIN_PA27
#define LED2	PIN_PB03
#define LED3	PIN_PA17

struct adc_module adc_instance;
struct adc_config config_adc;
uint16_t ADC_Result;
struct usart_config config_usart;
struct usart_module usart_instance;
uint8_t string1[] = "APP-ESS17-2 v1.10 Demo\r\n";
uint8_t StringBuf[64];

int main (void)
{
	uint8_t OLED_Page = 0;
	uint8_t OLED_Column = 0;
	uint8_t OLED_Start_line = 0;
	
	system_init();
	
	delay_init();
	
	adc_get_config_defaults(&config_adc);
	/*
	config->clock_source                  = GCLK_GENERATOR_0;
	config->reference                     = ADC_REFERENCE_INT1V;
	config->clock_prescaler               = ADC_CLOCK_PRESCALER_DIV4;
	config->resolution                    = ADC_RESOLUTION_12BIT;
	config->window.window_mode            = ADC_WINDOW_MODE_DISABLE;
	config->window.window_upper_value     = 0;
	config->window.window_lower_value     = 0;
	config->gain_factor                   = ADC_GAIN_FACTOR_1X;
	*/
	
	config_adc.reference = ADC_REFERENCE_INTVCC1;
	config_adc.positive_input = ADC_POSITIVE_INPUT_PIN5;
	adc_init(&adc_instance, ADC, &config_adc);
	adc_enable(&adc_instance);
	
	usart_get_config_defaults(&config_usart);
	config_usart.baudrate    = 9600;
	config_usart.mux_setting = USART_RX_3_TX_2_XCK_3;
	config_usart.pinmux_pad0 = PINMUX_UNUSED;
	config_usart.pinmux_pad1 = PINMUX_UNUSED;
	config_usart.pinmux_pad2 = PINMUX_PB22D_SERCOM5_PAD2;
	config_usart.pinmux_pad3 = PINMUX_PB23D_SERCOM5_PAD3;
	while (usart_init(&usart_instance, SERCOM5, &config_usart) != STATUS_OK);
	usart_enable(&usart_instance);

	//#define EDBG_CDC_SERCOM_DMAC_ID_TX   SERCOM5_DMAC_ID_TX
	//#define EDBG_CDC_SERCOM_DMAC_ID_RX   SERCOM5_DMAC_ID_RX

	ssd1306_init();
	ssd1306_set_page_address(OLED_Page);
	ssd1306_set_column_address(OLED_Column);
	ssd1306_set_display_start_line_address(OLED_Start_line);
	
	ioport_set_pin_dir(LED1, IOPORT_DIR_OUTPUT);
	ioport_set_pin_dir(LED2, IOPORT_DIR_OUTPUT);
	ioport_set_pin_dir(LED3, IOPORT_DIR_OUTPUT);
	
	ioport_set_pin_level(LED1, true);
	ioport_set_pin_level(LED2, true);
	ioport_set_pin_level(LED3, false);
	
	usart_write_buffer_wait(&usart_instance, string1, sizeof(string1));
	
	for (OLED_Page = 0; OLED_Page < 8; OLED_Page++)
	{
		ssd1306_set_page_address(OLED_Page);
		for (OLED_Column = 0; OLED_Column < 128; OLED_Column++)
		{
			ssd1306_set_column_address(OLED_Column);
			ssd1306_write_data(Microchip_Logo[(OLED_Page * 128) + OLED_Column]);
		}
	}

	delay_ms(500);
	
	for (OLED_Page = 0; OLED_Page < 8; OLED_Page++)
	{
		ssd1306_set_page_address(OLED_Page);
		for (OLED_Column = 0; OLED_Column < 128; OLED_Column++)
		{
			ssd1306_set_column_address(OLED_Column);
			ssd1306_write_data(WINSTAR_Logo[(OLED_Page * 128) + OLED_Column]);
		}
	}

	delay_ms(2000);
	
	for (OLED_Page = 0; OLED_Page < 8; OLED_Page++)
	{
		ssd1306_set_page_address(OLED_Page);
		for (OLED_Column = 0; OLED_Column < 128; OLED_Column++)
		{
			ssd1306_set_column_address(OLED_Column);
			ssd1306_write_data(Microchip_Logo[(OLED_Page * 128) + OLED_Column]);
		}
	}
	
	while(1)
	{
		ioport_toggle_pin_level(LED1);
		ioport_toggle_pin_level(LED2);
		ioport_toggle_pin_level(LED3);
		
		ssd1306_set_display_start_line_address(OLED_Start_line++);
		
		adc_start_conversion(&adc_instance);
		while (adc_read(&adc_instance, &ADC_Result) == STATUS_BUSY);
		
		sprintf((char * )StringBuf, "ADC Result : %4d\r\n",ADC_Result);
		usart_write_buffer_wait(&usart_instance, StringBuf, sizeof(StringBuf));

		delay_ms(100);
	}
}
